@@ -22,7 +22,4 @@
     KVM.  RHEL, SuSE, Fedora, CentOS, OracleLinux, ALT, Debian, Ubuntu,
     Mint and Kali are supported by this module. *)
 
-val convert : Guestfs.guestfs -> Types.source -> Types.inspect ->
-              Firmware.i_firmware -> Types.guestcaps_block_type ->
-              bool -> Types.static_ip list ->
-              Types.guestcaps
+module Convert_linux : Convert_types.CONVERT
